@@ -2,7 +2,7 @@
  *  \brief header for rational matrix functions set
  *
  *  \date Created: 2005
- *  \date Last modified: Time-stamp: <2006-05-26 14:35:51 antoine>
+ *  \date Last modified: Time-stamp: <2022-02-21 15:43:22 (antoine)>
  *
  *
  *  \note Licence: GPL (>= 2)
@@ -41,7 +41,7 @@ namespace matrixq
   /**
    * \brief C++ function use to transpose matrix
    */
-  bigvec_q bigq_transpose (const  bigvec_q & mat,int nr,int nc);
+  bigvec_q bigq_transpose (const  bigvec_q & mat);
 
 
 }
